--- loncom/interface/lonpickcourse.pm 2009/05/05 05:30:00 1.80
+++ loncom/interface/lonpickcourse.pm 2009/07/25 23:16:04 1.83
@@ -1,7 +1,7 @@
# The LearningOnline Network
# Pick a course
#
-# $Id: lonpickcourse.pm,v 1.80 2009/05/05 05:30:00 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.83 2009/07/25 23:16:04 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -51,22 +51,21 @@ sub handler {
($ENV{'QUERY_STRING'},['domainfilter','form','cnumelement',
'cdomelement','cnameelement','roleelement',
'multiple','type','setroles','fixeddom']);
-
my ($type,$title,$jscript,$multelement,$multiple,$roleelement,
$lastaction,$autosubmit,$submitopener);
# Get course type - Course or Non-standard Course.
$type = $env{'form.type'};
if (!defined($env{'form.type'})) {
$type = 'Course';
}
- $title = &mt('Selecting a [_1]',$type);
+ $title = 'Selecting a '.$type;
# Setup for multiple course selections, if flag for multiples set.
$multiple = $env{'form.multiple'};
if ($multiple) {
($jscript,$multelement) = &multiples_tag();
- $title = &mt('Selecting [_1](s)',lc($type));
+ $title = 'Selecting '.$type.'(s)';
}
# if called when a DC is selecting a course
@@ -423,12 +422,14 @@ sub multiples_tag {
sub build_filters {
my ($filterlist,$type,$roleelement,$multelement,$filter,$action,
- $numtitlesref) = @_;
+ $numtitlesref,$caller) = @_;
my $list;
my $formname;
my ($fixeddom,$codedom,$jscript);
if (defined($env{'form.form'})) {
- $formname = $env{'form.form'};
+ $formname = $env{'form.form'};
+ } else {
+ $formname = $caller;
}
my ($domainselectform,$sincefilterform,$ownerdomselectform,$persondomselectform,
$instcodeform,$typeselectform,$instcodetitle);
@@ -544,7 +545,7 @@ sub build_filters {
''."\n";
}
}
- foreach my $posstype ('Course','Non-standard Course') {
+ foreach my $posstype ('Course','Community') {
$typeselectform.='\n";
}
@@ -752,7 +753,7 @@ sub gochoose_javascript {
total => 'coursetotal',
list => 'courselist',
},
- 'Non-standard Course' => {
+ 'Community' => {
name => 'grouppick',
total => 'grouptotal',
list => 'grouplist',
@@ -869,7 +870,7 @@ Course Activity - how recently was cours
Course Domain - the domain of the course
=item *
-Course Type - Course or Non-standard Course
+Course Type - Course or Community
=item *
Course Institutional Code - the institutional identifier assigned to the course
@@ -922,7 +923,7 @@ Following selection, and/or submission,
X
B:
-Input: 1 - $type - the course type - Course or Non-standard Course
+Input: 1 - $type - the course type - Course or Community
Output: 1 - $output - javascript wrapped in EscriptEE/scriptE tags
@@ -954,10 +955,10 @@ Side Effects: None
=item *
X
-B:
+B:
-Input: 7 - anonymous array of search criteria; course type; $roleelement ; $multelement ; anonymous hash of criteria and their values; form action; ref to scalar (count of number of elements in institutional codes -- e.g., 4 for year, semester, department, and number).
+Input: 7 - anonymous array of search criteria; course type; $roleelement ; $multelement ; anonymous hash of criteria and their values; form action; ref to scalar (count of number of elements in institutional codes -- e.g., 4 for year, semester, department, and number); caller context (e.g., set to 'modifycourse' when routine is called from lonmodifycourse.pm).
Output: 1 - $output - HTML for display of search criteria, and hidden form elements.
@@ -51,22 +51,21 @@ sub handler {
my ($type,$title,$jscript,$multelement,$multiple,$roleelement,
$lastaction,$autosubmit,$submitopener);
- # Get course type - Course or Non-standard Course.
+ # Get course type - Course or Community.
$type = $env{'form.type'};
if (!defined($env{'form.type'})) {